{*******************************************************}
{                                                       }
{  VG Library II                                        }
{                                                       }
{  VCL Design Editors (DB Aware)                        }
{                                                       }
{  (c) 1997, 2001 by Vladimir Gaitanoff                 }
{                                                       }
{*******************************************************}

{$I vg2.inc}
{$D-,L-}

unit vg2DBDsgn;

interface
uses Classes, DsgnIntf, vg2VclDsgn;

type

{ TDBNavigatorEditor }

  TDBNavigatorEditor = class(TComponentEditor)
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

{ TDBStringProperty }

  TDBStringProperty = class(TListNamesProperty)
  public
    procedure GetValueList(List: TStrings); virtual; abstract;
    procedure GetValues(Proc: TGetStrProc); override;
  end;

{ TDataFieldProperty }

  TDataFieldProperty = class(TDBStringProperty)
  public
    function GetDataSourcePropName: string; virtual;
    procedure GetValueList(List: TStrings); override;
  end;

{ TListFieldProperty }

  TListFieldProperty = class(TDataFieldProperty)
  public
    function GetDataSourcePropName: string; override;
  end;

implementation
uses TypInfo, DB, ColnEdit,
  vg2Consts, vg2SysUtils, vg2DBNavigate;

{ TDBNavigatorEditor }

procedure TDBNavigatorEditor.ExecuteVerb(Index: Integer);
begin
  case Index of
    0: ShowCollectionEditor(Self.Designer, Component, Tvg2DBNavigator(Component).Buttons, 'Buttons');
  end;
end;

function TDBNavigatorEditor.GetVerb(Index: Integer): string;
begin
  case Index of
    0: Result := SShowDesigner;
  end;
end;

function TDBNavigatorEditor.GetVerbCount: Integer;
begin
  Result := 1;
end;

{ TDBStringProperty }

procedure TDBStringProperty.GetValues(Proc: TGetStrProc);
var
  Values: TStringList;
begin
  Values := TStringList.Create;
  try
    GetValueList(Values);
    EnumStrings(Values, Proc);
  finally
    Values.Free;
  end;
end;

{ TDataFieldProperty }

function TDataFieldProperty.GetDataSourcePropName: string;
begin
  Result := 'DataSource';
end;

procedure TDataFieldProperty.GetValueList(List: TStrings);
var
  Instance: TComponent;
  PropInfo: PPropInfo;
  DataSource: TDataSource;
begin
  Instance := GetComponent(0) as TComponent;
  PropInfo := TypInfo.GetPropInfo(Instance.ClassInfo, GetDataSourcePropName);
  if (PropInfo <> nil) and (PropInfo^.PropType^.Kind = tkClass) then
  begin
    DataSource := TObject(GetOrdProp(Instance, PropInfo)) as TDataSource;
    if (DataSource <> nil) and (DataSource.DataSet <> nil) then
      DataSource.DataSet.GetFieldNames(List);
  end;
end;

{ TListFieldProperty }

function TListFieldProperty.GetDataSourcePropName: string;
begin
  Result := 'ListSource';
end;

end.
